@@ -436,7 +436,7 @@ class Table(metaclass=MetaTable):
             cls.put_db(db)
 
     @classmethod
-    def all(cls, filter=[], order=[], search=[]):
+    def all(cls, filter={}, order={}, search={}):
         filter = cls.where(filter)
         search = cls.where(search, separator='OR')
 
@@ -467,7 +467,7 @@ class Table(metaclass=MetaTable):
         return result
 
     @classmethod
-    def filter(cls, page=1, limit=100, filter=[], order=[], search=[]):
+    def filter(cls, page=1, limit=100, filter={}, order={}, search={}):
         filter = cls.where(filter)
         search = cls.where(search, separator='OR')
         limit = min(limit, 100)
@@ -512,16 +512,17 @@ class Table(metaclass=MetaTable):
         return result
 
     @classmethod
-    def save(cls, id, data):
+    def save(cls, id, data, where={}):
+        where = cls.where(where)
         update = cls.update(data)
         try:
             db = cls.get_db()
             cursor = db.cursor()
             cursor.execute(*debug(f"""UPDATE {cls}
                                     SET {update.fields()}
-                                    WHERE {cls('id')}=%s
+                                    WHERE {cls('id')}=%s AND {where.fields()}
                                     RETURNING {cls.select()}""",
-                                update.values(id)))
+                                update.values(id)+where.values()))
             result = cls.create(cursor.fetchone())
         except Exception as error:
             raise error
